Package: Ternary
Version: 2.3.7
Title: Create Ternary and Holdridge Plots
Description: Plots ternary diagrams (simplex plots / Gibbs triangles) and
  Holdridge life zone plots <doi:10.1126/science.105.2727.367> using the
  standard graphics functions.
  Allows custom annotation, interpolating, contouring and scaling of plotting
  region.
  Includes a 'Shiny' user interface for point-and-click ternary plotting.
  An alternative to 'ggtern', which uses the 'ggplot2' family of plotting 
  functions.
URL: https://ms609.github.io/Ternary/,
        https://github.com/ms609/Ternary/
BugReports: https://github.com/ms609/Ternary/issues/
Authors@R: c(person("Martin R.", "Smith",
                    email = "martin.smith@durham.ac.uk",
                    role = c("aut", "cre", "cph"), 
                    comment = c(ORCID = "0000-0001-5660-1727")
                   ),
             person("Lilian", "Sanselme", role = "ctb")
            )
License: GPL (>= 2)
Language: en-GB
Depends: R (>= 3.6.0)
Imports: PlotTools (>= 0.2.0), shiny, sp, clue,
Suggests: colourpicker, knitr, readxl, rmarkdown, shinyjs, spelling,
        testthat (>= 3.0), vdiffr,
Config/Needs/check: rcmdcheck
Config/Needs/coverage: covr
Config/Needs/memcheck: devtools, rcmdcheck
Config/Needs/metadata: codemeta
Config/Needs/revdeps: revdepcheck
Config/Needs/website: pkgdown, shinylive
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
Config/testthat/parallel: false
LazyData: true
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-06-04 05:42:31 UTC; pjjg18
Author: Martin R. Smith [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-5660-1727>),
  Lilian Sanselme [ctb]
Maintainer: Martin R. Smith <martin.smith@durham.ac.uk>
Repository: CRAN
Date/Publication: 2026-06-04 15:40:02 UTC
Built: R 4.5.2; ; 2026-06-04 18:54:10 UTC; unix
