# Generated by roxygen2: do not edit by hand

S3method(.SetRegion,data.frame)
S3method(.SetRegion,list)
S3method(.SetRegion,matrix)
S3method(.SetRegion,ternRegion)
S3method(TernaryToXY,matrix)
S3method(TernaryToXY,numeric)
export(.SetRegion)
export(AddToHoldridge)
export(AddToTernary)
export(Annotate)
export(ColorTernary)
export(ColourTernary)
export(CoordinatesToXY)
export(GrowPolygon)
export(HoldridgeArrows)
export(HoldridgeBelts)
export(HoldridgeHypsometricCol)
export(HoldridgeLines)
export(HoldridgePlot)
export(HoldridgePoints)
export(HoldridgePolygon)
export(HoldridgeText)
export(HoldridgeToXY)
export(HorizontalGrid)
export(JoinTheDots)
export(OutsidePlot)
export(PolygonArea)
export(PolygonCenter)
export(PolygonCentre)
export(ReflectedEquivalents)
export(TernaryApp)
export(TernaryArrows)
export(TernaryContour)
export(TernaryCoords)
export(TernaryDensity)
export(TernaryDensityContour)
export(TernaryDownTiles)
export(TernaryLeftTiles)
export(TernaryLines)
export(TernaryPlot)
export(TernaryPointValues)
export(TernaryPoints)
export(TernaryPolygon)
export(TernaryRightTiles)
export(TernarySegments)
export(TernaryText)
export(TernaryTiles)
export(TernaryToXY)
export(TernaryUpTiles)
export(TernaryXRange)
export(TernaryYRange)
export(TriangleCentres)
export(TriangleInHull)
export(XYToHoldridge)
export(XYToPetPrec)
export(XYToTernary)
importFrom(PlotTools,GrowPolygon)
importFrom(PlotTools,PolygonArea)
importFrom(PlotTools,PolygonCenter)
importFrom(PlotTools,SpectrumLegend)
importFrom(TreeDist,LAPJV)
importFrom(grDevices,chull)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,xy.coords)
importFrom(graphics,.filled.contour)
importFrom(graphics,arrows)
importFrom(graphics,contour)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(shiny,runApp)
importFrom(shiny,runGitHub)
importFrom(sp,point.in.polygon)
importFrom(stats,dnorm)
importFrom(stats,quantile)
importFrom(stats,var)
