app <- ShinyDriver$new("../../")
app$snapshotInit("plotOptions")

app$snapshot()
app$setInputs(dim2 = "Fsp")
app$setInputs(dim1 = "Qz")
app$setInputs(dim3 = "RF")
app$setInputs(point = "right")
app$setInputs(col = "#E3B6B6")
app$setInputs(`axis.lwd` = 2.03)
app$setInputs(`axis.lty` = "dotted")
app$setInputs(`axis.col` = "#F51B1B")
app$setInputs(`ticks.lwd` = 2.71)
app$setInputs(`ticks.length` = 0.033)
app$setInputs(`ticks.col` = "#30948D")
app$setInputs(display = c("show.tip.labels", "show.axis.labels",
                          "axis.labels", "axis.tick", "axis.rotate"))
app$setInputs(`grid.lines` = 7)
app$setInputs(`grid.minor.lines` = 3)
app$setInputs(`grid.col` = "#245DA6")
app$setInputs(`grid.minor.col` = "#19779C")
app$setInputs(`grid.lty` = "dotted")
app$setInputs(`grid.minor.lty` = "dotdash")
app$setInputs(`grid.lwd` = 1.67)
app$setInputs(`grid.minor.lwd` = 1.25)
app$setInputs(`grid.lwd` = 2.54)
app$setInputs(`lab.font` = "2")
app$setInputs(`axis.font` = "2")
app$setInputs(`tip.font` = "4")
app$setInputs(`tip.cex` = 1.14)
app$setInputs(`axis.cex` = 0.96)
app$setInputs(`lab.offset` = 0.215)
app$setInputs(`points.type` = "b")
app$setInputs(`points.pch` = "11")
app$setInputs(`points.col` = "#E01919")
app$setInputs(`points.cex` = 2.27)
app$setInputs(`points.lwd` = 1.65)
app$setInputs(`points.lty` = "longdash")
app$setInputs(pngSize = 850)
app$snapshot()
app$setInputs(display = c("show.tip.labels", "show.axis.labels",
                          "axis.labels", "axis.tick"))
app$snapshot()
app$setInputs(display = character(0))
app$snapshot()
